summaryrefslogtreecommitdiff
path: root/platform/projectModel-api/src/com/intellij/openapi/roots/ProjectFileIndex.java
diff options
context:
space:
mode:
Diffstat (limited to 'platform/projectModel-api/src/com/intellij/openapi/roots/ProjectFileIndex.java')
-rw-r--r--platform/projectModel-api/src/com/intellij/openapi/roots/ProjectFileIndex.java15
1 files changed, 11 insertions, 4 deletions
diff --git a/platform/projectModel-api/src/com/intellij/openapi/roots/ProjectFileIndex.java b/platform/projectModel-api/src/com/intellij/openapi/roots/ProjectFileIndex.java
index 8ada83981017..b06cf065fd95 100644
--- a/platform/projectModel-api/src/com/intellij/openapi/roots/ProjectFileIndex.java
+++ b/platform/projectModel-api/src/com/intellij/openapi/roots/ProjectFileIndex.java
@@ -129,11 +129,18 @@ public interface ProjectFileIndex extends FileIndex {
boolean isInLibrarySource(@NotNull VirtualFile fileOrDir);
/**
- * Checks if the specified file or directory is ignored (either excluded by exclude roots
- * or ignored by {@link com.intellij.openapi.fileTypes.FileTypeManager#isFileIgnored(String)}).
+ * @deprecated name of this method may be confusing. If you want to check if the file is excluded or ignored use {@link #isExcluded(com.intellij.openapi.vfs.VirtualFile)}.
+ * If you want to check if the file is ignored use {@link com.intellij.openapi.fileTypes.FileTypeRegistry#isFileIgnored(com.intellij.openapi.vfs.VirtualFile)}.
+ */
+ @Deprecated
+ boolean isIgnored(@NotNull VirtualFile file);
+
+ /**
+ * Checks if the specified file or directory is located under project roots but the file itself or one of its parent directories is
+ * either excluded from the project or ignored by {@link com.intellij.openapi.fileTypes.FileTypeRegistry#isFileIgnored(com.intellij.openapi.vfs.VirtualFile)}).
*
* @param file the file to check.
* @return true if <code>file</code> is ignored, false otherwise.
*/
- boolean isIgnored(@NotNull VirtualFile file);
+ boolean isExcluded(@NotNull VirtualFile file);
}
@@ -129,11 +129,18 @@ public interface ProjectFileIndex extends FileIndex {
*
* @param file the file to check.
- * @return true if <code>file</code> is ignored, false otherwise.
+ * @return true if <code>file</code> is excluded or ignored, false otherwise.
*/